@@ -296,7 +296,7 @@ class Channel:
         raw = _src(f'{self._url}/videos?view=0&sort=dd&flow=grid')
         block_data = re.findall('gridVideoRenderer\":{(.*?)\"navigationEndpoint', raw)
         filtered = [data for data in block_data if 'simpleText":"Streamed' not in data]
-        more = [data for data in block_data if '{"text":" watching"}]' not in data]
+        more = [data for data in filtered if '{"text":" watching"}]' not in data]
         if more:
             target_source = more[0]
             return Video(re.findall('videoId\":\"(.*?)\"', target_source)[0])
